@@ -18,7 +18,7 @@ test_that("convertGDP different column names", {
   gdp_in1 <- wb_wdi %>%
     dplyr::filter(!iso3c %in% bad_countries,
                   !is.na(`GDP, PPP (constant 2017 international $)`)) %>%
-    dplyr::select("r"=iso3c, year, "value" = `GDP (current LCU)`)
+    dplyr::select("r" = iso3c, year, "value" = `GDP (current LCU)`)
   gdp_in1b <- dplyr::mutate(gdp_in1, r = "")
 
   gdp_in2 <- wb_wdi %>%
@@ -30,12 +30,18 @@ test_that("convertGDP different column names", {
   expect_warning(
       convertGDP(gdp_in1, "current LCU", "constant 2017 Int$PPP", wb_wdi)
     )
+  expect_no_warning(
+    convertGDP(gdp_in1, "current LCU", "constant 2017 Int$PPP", wb_wdi, iso3c_column = "r")
+  )
   expect_error(
       convertGDP(gdp_in1b, "current LCU", "constant 2017 Int$PPP", wb_wdi)
   )
   expect_warning(
     convertGDP(gdp_in2, "current LCU", "constant 2017 Int$PPP", wb_wdi)
   )
+  expect_no_warning(
+    convertGDP(gdp_in2, "current LCU", "constant 2017 Int$PPP", wb_wdi, year_column = "y")
+  )
   expect_error(
     convertGDP(gdp_in2b, "current LCU", "constant 2017 Int$PPP", wb_wdi)
   )
@@ -129,39 +135,67 @@ test_that("convertGDP missing conversion factors", {
 
 
 
-test_that("convertGDP with regions", {
-  gdp <- tibble::tibble("iso3c" = c("JPN", "EUR", "DEU"), "year" = 2010, "value" = 100)
-  gdp2 <- tibble::tibble("region" = c("JPN", "EUR", "DEU"), "period" = 2010, "value" = 100)
-  with_regions <- tibble::tibble("iso3c" = c("FRA", "ESP", "DEU"), "region" = "EUR")
+test_that("convertGDP with regions, custom data-frame", {
+  gdp <- tibble::tibble("iso3c" = c("JPN", "DEU", "ESP", "FRA", "EUR"), "value" = 100)
+  with_regions <- tibble::tibble("iso3c" = c("DEU", "ESP", "FRA"), "region" = "EUR")
 
   gdp_conv <- convertGDP(gdp,
                          unit_in = "constant 2015 Int$PPP",
                          unit_out = "constant 2017 Int$PPP",
                          with_regions = with_regions)
 
-  gdp_conv2 <- suppressWarnings(suppressWarnings(
-    convertGDP(gdp2,
-               unit_in = "constant 2015 Int$PPP",
-               unit_out = "constant 2017 Int$PPP",
-               with_regions = with_regions)
-  ))
+  expect_equal(gdp$iso3c, gdp_conv$iso3c)
+  expect_true(all(!is.na(gdp_conv$value)))
 
-  gdp_conv_b <- convertGDP(gdp,
-                           unit_in = "constant 2017 Int$PPP",
-                           unit_out = "constant 2017 Int$PPP",
-                           with_regions = with_regions)
+  shares <- wb_wdi %>%
+    dplyr::select("iso3c", "year", "value" = "GDP, PPP (constant 2017 international $)") %>%
+    dplyr::left_join(dplyr::rename(with_regions, "gdpuc_region" = "region"), by = "iso3c") %>%
+    dplyr::filter(.data$year == 2015, !is.na(.data$gdpuc_region)) %>%
+    convertGDP("constant 2017 Int$PPP", "constant 2015 Int$PPP", source = wb_wdi, verbose = FALSE) %>%
+    dplyr::mutate(share = .data$value / sum(.data$value, na.rm = TRUE), .by = "gdpuc_region")
 
-  gdp_conv3 <- convertGDP(gdp,
-                          unit_in = "constant 2015 US$MER",
+  gdp2 <- tibble::tibble("iso3c" = c("JPN", "DEU", "ESP", "FRA", "EUR"),
+                         "value" = c(100, 100 * shares$share[1], 100 * shares$share[2], 100 * shares$share[3], 100))
+
+  gdp_conv2 <- convertGDP(gdp2,
+                          unit_in = "constant 2015 Int$PPP",
                           unit_out = "constant 2017 Int$PPP",
                           with_regions = with_regions)
 
-  expect_equal(gdp$iso3c, gdp_conv$iso3c)
-  expect_equal(gdp_conv$value, gdp_conv2$value)
-  expect_true(all(gdp_conv3$value != gdp_conv$value))
+  expect_equal(sum(gdp_conv2$value[2:4]), gdp_conv2$value[5])
+
+
+  shares <- wb_wdi %>%
+    dplyr::select("iso3c", "year", "value" = "GDP (constant 2015 US$)") %>%
+    dplyr::left_join(dplyr::rename(with_regions, "gdpuc_region" = "region"), by = "iso3c") %>%
+    dplyr::filter(.data$year == 2015, !is.na(.data$gdpuc_region)) %>%
+    convertGDP("constant 2015 US$MER", "constant 2015 US$MER", source = wb_wdi, verbose = FALSE) %>%
+    dplyr::mutate(share = .data$value / sum(.data$value, na.rm = TRUE), .by = "gdpuc_region")
+
+  gdp2 <- tibble::tibble("iso3c" = c("JPN", "DEU", "ESP", "FRA", "EUR"),
+                         "value" = c(100, 100 * shares$share[1], 100 * shares$share[2], 100 * shares$share[3], 100))
+
+  gdp_conv2 <- convertGDP(gdp2,
+                          unit_in = "constant 2015 US$MER",
+                          unit_out = "constant 2017 US$MER",
+                          with_regions = with_regions)
+
+  expect_equal(sum(gdp_conv2$value[2:4]), gdp_conv2$value[5])
+})
+
+test_that("convertGDP with regions, madrat data-frame", {
+  skip_if_not_installed("madrat")
+  gdp <- tibble::tibble("iso3c" = c("JPN", "EUR", "DEU"), "value" = 100)
+  expect_no_warning(convertGDP(gdp,
+                               unit_in = "constant 2015 Int$PPP",
+                               unit_out = "constant 2017 Int$PPP",
+                               with_regions = "regionmappingH12.csv"))
+
 })
 
 test_that("convertGDP using US conversion factors", {
+  skip_if_not_installed("zoo")
+
   gdp_1 <- tibble::tibble("iso3c" = "USA", "year" = 2010, "value" = 100)
   gdp_2 <- tibble::tibble("iso3c" = "DEU", "year" = 2010, "value" = 100)
   gdp_3 <- tibble::tibble("iso3c" = "JJJ", "year" = 2010, "value" = 100)
@@ -172,7 +206,7 @@ test_that("convertGDP using US conversion factors", {
   gdp2_conv <- convertGDP(gdp_2,
                           unit_in = "constant 2015 LCU",
                           unit_out = "constant 2017 LCU",
-                          use_USA_deflator_for_all = TRUE)
+                          use_USA_cf_for_all = TRUE)
   gdp3_conv <- convertGDP(gdp_3,
                           unit_in = "constant 2015 LCU",
                           unit_out = "constant 2017 LCU",
@@ -182,35 +216,23 @@ test_that("convertGDP using US conversion factors", {
   expect_equal(gdp1_conv, gdp3_conv %>% dplyr::mutate(iso3c = "USA"))
 })
 
-test_that("convertCPI", {
-  gdp_1 <- tibble::tibble("iso3c" = "USA", "year" = 2010, "value" = 100)
+test_that("convert euros", {
+  gdp1_conv <- convertSingle(100, "USA",
+                             unit_in = "constant 2015 LCU",
+                             unit_out = "constant 2017 €")
 
-  gdp1_conv <- convertCPI(gdp_1,
-                          unit_in = "constant 2015 LCU",
-                          unit_out = "constant 2017 LCU")
-  gdp2_conv <- convertGDP(gdp_1,
-                          unit_in = "constant 2015 LCU",
-                          unit_out = "constant 2017 LCU",
-                          source = "wb_wdi_cpi")
+  gdp2_conv <- convertSingle(100, "USA",
+                             unit_in = "constant 2015 LCU",
+                             unit_out = "constant 2017 EUR")
+
+  gdp3_conv <- convertSingle(100, "DEU",
+                             unit_in = "constant 2010 LCU",
+                             unit_out = "constant 2017 €")
+
+  gdp4_conv <- convertSingle(100, "DEU",
+                             unit_in = "constant 2010 €",
+                             unit_out = "constant 2017 LCU")
 
   expect_equal(gdp1_conv, gdp2_conv)
-})
-
-
-test_that("convertSingle", {
-  gdp_1 <- tibble::tibble("iso3c" = "USA", "year" = 2010, "value" = 100)
-
-  gdp1_conv <- convertGDP(gdp_1,
-                          unit_in = "constant 2015 LCU",
-                          unit_out = "constant 2017 LCU")
-  gdp2_conv <- convertSingle(100, "USA", 2010,
-                             unit_in = "constant 2015 LCU",
-                             unit_out = "constant 2017 LCU")
-  gdp3_conv <- convertSingle(100, "USA", 2010,
-                             unit_in = "constant 2015 LCU",
-                             unit_out = "constant 2017 LCU",
-                             return_cfs = TRUE)
-
-  expect_equal(gdp1_conv$value, gdp2_conv)
-  expect_equal(gdp1_conv, gdp3_conv$result)
+  expect_equal(gdp3_conv, gdp4_conv)
 })
